<?php
/**
 * Zoo_Mega_Menu_Walker_Edit
 *
 * @package  Core\MegaMenu
 */

if (!class_exists('Walker_Nav_Menu_Edit')) {
	require ABSPATH.'wp-admin/includes/nav-menu.php';
}

final class Zoo_Mega_Menu_Walker_Edit extends Walker_Nav_Menu_Edit
{
	/**
	 * Start the element output.
	 *
	 * @see   Walker_Nav_Menu::start_el()
	 * @since 3.0.0
	 *
	 * @global int   $_wp_nav_menu_max_depth
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $item   Menu item data object.
	 * @param int    $depth  Depth of menu item. Used for padding.
	 * @param array  $args   Not used.
	 * @param int    $id     Not used.
	 */
	public function start_el(&$output, $item, $depth = 0, $args = [], $id = 0)
    {
		$item_hide_text       = get_post_meta($item->ID, 'zoo_menu_item_hide_text', true);
		$item_hot             = get_post_meta($item->ID, 'zoo_menu_item_hot', true);
		$item_new             = get_post_meta($item->ID, 'zoo_menu_item_new', true);
		$item_trending        = get_post_meta($item->ID, 'zoo_menu_item_trending', true);
		$item_disable_link    = get_post_meta($item->ID, 'zoo_menu_item_disable_link', true);
		$item_content         = get_post_meta($item->ID, 'zoo_menu_item_content', true);
		$item_mega            = get_post_meta($item->ID, 'zoo_menu_item_mega', true);
		$item_mega_width      = get_post_meta($item->ID, 'zoo_menu_item_width', true);
		$mega_width           = get_post_meta($item->ID, 'zoo_menu_item_mega_width', true);

		$item_mega_background = wp_parse_args(
			get_post_meta($item->ID, 'zoo_menu_item_background', true),
			[
				'image'     =>'',
				'color'     =>'',
				'attachment'=>'scroll',
				'size'      =>'',
				'repeat'    =>'no-repeat',
				'position'  => [
					'x'     =>'left',
					'y'     =>'top',
					'custom'=> [
						'x'=>'',
						'y'=>'',
					]
				]
			]
		);

        $item_content_image = get_post_meta($item->ID, 'zoo_menu_item_contentImage', true);

		$item_output ='';
		parent::start_el($item_output, $item, $depth, $args);

		$dom = new DOMDocument();
		$dom->validateOnParse = true;
		$dom->loadHTML(mb_convert_encoding($item_output, 'HTML-ENTITIES', 'UTF-8'));

		$xpath = new DOMXPath($dom);

		// Add more menu item data
		$settings = $xpath->query("//*[@id='menu-item-settings-" . $item->ID . "']")->item(0);

		if ($settings) {
			$data     = $dom->createElement('span');
			$data->setAttribute('class', 'hidden zoo-data');
			$data->setAttribute('data-menu-item-id', intval($item->ID));
			$data->setAttribute('data-mega', intval($item_mega));
			$data->setAttribute('data-mega_width', esc_attr($mega_width));
			$data->setAttribute('data-width', esc_attr($item_mega_width));
			$data->setAttribute('data-background', json_encode($item_mega_background));
			$data->setAttribute('data-content-image', esc_attr($item_content_image));
			$data->setAttribute('data-hide-text', intval($item_hide_text));
			$data->setAttribute('data-hot', intval($item_hot));
			$data->setAttribute('data-new', intval($item_new));
			$data->setAttribute('data-trending', intval($item_trending));
			$data->setAttribute('data-disable-link', intval($item_disable_link));
			$data->nodeValue = $item_content;

			$settings->appendChild($data);
		}

		$output .= $dom->saveHTML();
	}
}
