<?php
/**
 * Zoo_Setup_Demo_Page
 *
 * @package  Zoo_Theme\Core\Admin\Classes
 * @author   Zootemplate
 * @link     http://www.zootemplate.com
 *
 */
final class Zoo_Setup_Demo_Page
{
    /**
     * Slug
     */
    const SLUG = 'zoo-theme-setup-demo';

    /**
     * Hook suffix
     */
    public $hook_suffix;

    /**
     * Settings
     *
     * @var  array
     */
    protected $settings;

    /**
     * Theme
     */
    protected $theme;

    /**
     * Constructor
     */
    private function __construct()
    {
        $this->theme = zoo_get_parent_theme_object();
        $this->settings = (array)get_option(ZOO_SETTINGS_KEY) ? : [];
    }

    /**
     * Singleton
     */
    static function getInstance()
    {
        static $self = null;

        if (null === $self) {
            $self = new self;
            add_action('admin_menu', [$self, '_add'], 13);
            add_action('wp_ajax_zoo_setup_demo_content', [$self, '_setUpDemo'], 10, 0);
            add_action('wp_ajax_zoo_uninstall_demo_content', [$self, '_uninstallDemo'], 10, 0);
        }
    }

    /**
     * Add to admin menu
     */
    function _add($context = '')
    {
        $this->hook_suffix = zoo_add_submenu_page(
            Zoo_Welcome_Page::SLUG,
            esc_html__('Setup Demo Data', 'ciao'),
            esc_html__('Setup Demo Data', 'ciao'),
            'manage_options',
            self::SLUG,
            array($this, '_render')
        );
    }

    /**
     * Render
     */
    function _render()
    {
		$folders = new DirectoryIterator(ZOO_THEME_DIR . 'inc/sample-data');
		$demo    = get_theme_mod('theme_setup_site_style', 'default');
        $parser  = new Zoo_WXR_Parser();

        ?><div class="zoo-theme-setup-site-demo">
			<h2 class="screen-reader-text"><?php esc_html_e('Setup site demo', 'ciao') ?></h2>
            <div class="theme-presets">
                <ul class="demo-list"><?php
                    foreach ($folders as $folder) :
						if ($folder->isDot() || !$folder->isDir() || !$folder->isReadable()) {
							continue;
						}
						$style = $folder->getFilename();
						if ('base' === $style || !is_readable(ZOO_THEME_DIR . 'inc/sample-data/'.$style.'/content.xml')) continue;
                        $xml_data = $parser->parse(ZOO_THEME_DIR . 'inc/sample-data/'.$style.'/content.xml');
                        if (is_wp_error($xml_data)) continue;
	                    ?><li class="demo-item <?php echo esc_attr($style === $demo ? 'current ' : ''); ?>">
                            <div class="demo-content">
                                <img class="demo-thumbnail" src="<?php echo ZOO_THEME_URI . 'inc/sample-data/'.$style.'/screen.jpg' ?>">
                                <?php if ($style === $demo) : ?>
                                    <span class="demo-label"><?php esc_html_e('Installed', 'ciao') ?></span>
                                <?php endif ?>
                            </div>
                            <div class="demo-footer">
                                <span class="demo-title"><?php echo  esc_html($xml_data['posts'][0]['post_title']) ?></span>
                                <span class="demo-actions">
                                    <img class="demo-spinner" src="<?php echo admin_url('images/spinner.gif') ?>" alt="<?php esc_html_e('Installing', 'ciao') ?>">
                                    <a class="demo-preview" href="<?php echo esc_url($xml_data['posts'][0]['_link']) ?>" target="_blank"><?php esc_html_e('Preview', 'ciao') ?></a>
                                    <span class="sep">|</span>
                                    <?php
                                        if ($style === $demo) {
                                            $button_name = esc_html__('Uninstall', 'ciao');
                                            $action = $button_class = 'uninstall';
                                        } else {
                                            $button_name = esc_html__('Install', 'ciao');
                                            $action = $button_class = 'install';
                                        }
                                        printf('<a type="button" data-style="%s" data-action="%s" class="demo-import %s">%s</a>', esc_attr($style), esc_attr($action), esc_attr($button_class), esc_attr($button_name));
                                    ?>
                                </span>
                            </div>
                        </li><?php
					endforeach;
				?></ul>
            </div>
        </div><?php
    }

    /**
     * Setup demo
     */
    function _setUpDemo()
    {
        if (!current_user_can('manage_options')) {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Cheating, huh!', 'ciao')
            ]));
        }

        if (empty($_POST['zoo_demo_slug'])) {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Invalid demo ID.', 'ciao')
            ]));
        }

        $demo_importer = new Zoo_Demo_Importer();
        $is_base_content_installed = get_option($this->theme->template.'_base_content_installed');

        if (!$is_base_content_installed) {
            if (!is_readable(ZOO_THEME_DIR . 'inc/sample-data/base/content.xml')) {
                exit(json_encode([
                    'success' => false,
                    'message' => esc_html__('Base content file not found.', 'ciao')
                ]));
            }
            $ok = $demo_importer->importContent(ZOO_THEME_DIR . 'inc/sample-data/base/content.xml');
            if ($ok !== true) {
                exit(json_encode([
                    'success' => false,
                    'message' => esc_html__('Failed to import base content.', 'ciao') . ' ' . $ok->getMessage()
                ]));
            }
            if (is_readable(ZOO_THEME_DIR . 'inc/sample-data/base/slider.zip')) {
                $demo_importer->importRevSliders(ZOO_THEME_DIR . 'inc/sample-data/base/slider.zip');
            }
            if (is_readable(ZOO_THEME_DIR . 'inc/sample-data/base/widgets.wie')) {
                $demo_importer->importWidgets(ZOO_THEME_DIR . 'inc/sample-data/base/widgets.wie');
            }
            if (is_readable(ZOO_THEME_DIR . 'inc/sample-data/base/customizer.dat')) {
                $demo_importer->importThemeOptions(ZOO_THEME_DIR . 'inc/sample-data/base/customizer.dat');
            }
            if (is_dir(ZOO_THEME_DIR . 'inc/sample-data/base/settings')) {
                $demo_importer->importThemeSettings(ZOO_THEME_DIR . 'inc/sample-data/base/settings/');
            }
            update_option($this->theme->template.'_base_content_installed', time());
        }

        $demo_slug = sanitize_title($_POST['zoo_demo_slug']);

        if (!is_readable(ZOO_THEME_DIR . 'inc/sample-data/' . $demo_slug . '/content.xml')) {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Demo content file not found.', 'ciao')
            ]));
        }

		$xml_parser = new Zoo_WXR_Parser();
		$content = $xml_parser->parse(ZOO_THEME_DIR . 'inc/sample-data/' . $demo_slug . '/content.xml');
		$home_id = $content['posts'][0]['post_id'];
        $imported_content = get_transient('_wxr_imported_content') ? : [];

		if ( isset($imported_content['posts'][$home_id]) ) {
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $imported_content['posts'][$home_id] );
		} else {
			$ok = $demo_importer->importContent(ZOO_THEME_DIR . 'inc/sample-data/' . $demo_slug . '/content.xml');
            if (true !== $ok) {
                exit(json_encode([
                    'success' => false,
                    'message' => esc_html__('Failed to import demo content.', 'ciao') . ' ' . $ok->getMessage()
                ]));
            }
			$imported_content = get_transient('_wxr_imported_content') ? : [];
			update_option( 'show_on_front', 'page' );
			update_option( 'page_on_front', $imported_content['posts'][$home_id] );
		}

        set_theme_mod('theme_setup_site_style', $demo_slug);

        exit(json_encode([
            'success' => true,
            'message' => esc_html__('Demo data installed successfully!', 'ciao')
        ]));
    }

    /**
     * Uninstall demo page
     */
    function _uninstallDemo()
    {
        if (!current_user_can('manage_options')) {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Cheating, huh!', 'ciao')
            ]));
        }

        if (empty($_POST['zoo_demo_slug'])) {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Invalid demo ID.', 'ciao')
            ]));
        }

		update_option( 'show_on_front', '' );

        $removed = update_option( 'page_on_front', '' );

        if ($removed) {
            set_theme_mod('theme_setup_site_style', '');
            exit(json_encode([
                'success' => true,
                'message' => esc_html__('Demo page has been uninstalled successfully.', 'ciao')
            ]));
        } else {
            exit(json_encode([
                'success' => false,
                'message' => esc_html__('Failed to uninstall demo page.', 'ciao')
            ]));
        }
    }
}
Zoo_Setup_Demo_Page::getInstance();
