<?php

/**
 * Zoo_Customize_Builder_Element_Logo
 *
 * @package  Zoo_Theme\Core\Customize\Builder\Elements
 * @author   Zootemplate
 * @link     http://www.zootemplate.com
 *
 */
final class Zoo_Customize_Builder_Element_Logo extends Zoo_Customize_Builder_Element
{
    function __construct()
    {
        $this->id = 'logo';
        $this->title = esc_html__('Site Identity', 'ciao');
        $this->width = 3;
        $this->selector = '.site-branding';
        $this->section = 'title_tagline';
        $this->panel = 'header_settings';
    }

    function get_builder_configs()
    {
        return [
            'name' => $this->title,
            'id' => $this->id,
            'width' => $this->width,
            'section' => $this->section
        ];
    }

    function get_customize_configs(WP_Customize_Manager $wp_customize = null)
    {
        $config = [
            [
                'name' => 'header_logo_max_width',
                'type' => 'slider',
                'section' => $this->section,
                'default' => [],
                'max' => 400,
                'title' => esc_html__('Logo Max Height', 'ciao'),
                'selector' => $this->selector . ' .wrap-logo .site-logo',
                'css_format' => 'max-height: {{value}};',
                'device_settings' => true
            ],
            [
                'name' => 'header_logo_name',
                'type' => 'radio_group',
                'section' => $this->section,
                'selector' => $this->selector,
                'title' => esc_html__('Show Site Title', 'ciao'),
                'default' => 'yes',
                'choices' => [
                    'no' => esc_html__('No', 'ciao'),
                    'yes' => esc_html__('Yes', 'ciao'),
                ],
                'render_callback' => [$this, 'render']
            ],
            [
                'name' => 'header_logo_text_color',
                'type' => 'color',
                'section' => $this->section,
                'title' => esc_html__('Site Title Color', 'ciao'),
                'css_format' => '.site-branding .site-name a {color: {{value}};}',
                'selector' => 'format',
                'required' => ['header_logo_name', '==', 'yes']
            ],
            [
                'name' => 'header_logo_desc',
                'type' => 'radio_group',
                'section' => $this->section,
                'selector' => $this->selector,
                'title' => esc_html__('Show Site Tagline', 'ciao'),
                'default' => 'no',
                'choices' => [
                    'no' => esc_html__('No', 'ciao'),
                    'yes' => esc_html__('Yes', 'ciao'),
                ],
                'render_callback' => [$this, 'render']
            ],
        ];

        return array_merge($config, $this->get_layout_configs('#site-header'));
    }

    /**
     * Render
     *
     * @internal  Used as a callback.
     */
    public function render()
    {
        $args  = func_get_args();
        $align = zoo_customize_get_setting($this->builder_id.'_'.$this->id.'_align');

        $atts = [
            'logo_img' => '',
            'site_name' => ('yes' == zoo_customize_get_setting('header_logo_name')) ? get_bloginfo('name') : '',
            'site_desc' => ('yes' == zoo_customize_get_setting('header_logo_desc')) ? get_bloginfo('description') : ''
        ];

        if ($align) {
            if (!empty($args[1]) && is_array($align)) {
                $align = $align[$args[1]];
            }
            $atts['align'] = $align;
        }

        $atts['device'] = $args[1];

        $logo_id = zoo_customize_get_setting('custom_logo');
        $sticky_logo_id = zoo_customize_get_setting('header_sticky_logo');

        if ($logo_id) {
            $atts['logo_img'] = wp_get_attachment_url($logo_id, 'full');
        }
        $atts['sticky_logo_img'] = !empty($sticky_logo_id['url']) ? esc_url($sticky_logo_id['url']) : false;

        $tpl = apply_filters('header/element/logo', ZOO_THEME_DIR . 'core/customize/templates/header/element-logo.php', $atts);

        require $tpl;
    }
}

Zoo_Customize_Builder::get_instance()->add_element('header', new Zoo_Customize_Builder_Element_Logo());
